{% load i18n admin_urls %}

<div class="submit-row">
  {% if show_save %}
    <input type="submit" value="{% trans 'Save' %}" class="default" name="_save" />
  {% endif %}

  {% if show_delete_link %}
    {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
    <p class="deletelink-box">
      <a href="{% add_preserved_filters delete_url %}" class="deletelink">
        {% trans "Delete" %}
      </a>
    </p>
  {% endif %}

  {% if show_save_and_add_another %}
    <input type="submit" value="{% trans 'Save as new' %}" name="_saveasnew" />
  {% endif %}

  {% if show_save_and_add_another %}
    <input type="submit" value="{% trans 'Save and add another' %}" name="_addanother" />
  {% endif %}

  {% if show_save_and_continue %}
    <input type="submit" value="{% trans 'Save and continue editing' %}" name="_continue" />
  {% endif %}
</div>
